@@ -517,47 +517,8 @@ class API:
         self.websocket = WebsocketClient(self)
 
     async def refresh_ws_token(self) -> None:
-        reg_state = self.state.get("registration", {})
-        android_state = self.state.get("android", {})
-        if reg_id := reg_state.get("reg_id"):
-            await self.delete_registration(reg_id)
-        self._reg_id = await self.post_registration()
-        await self.delete_registration(self._reg_id)
-        reg_dict: RegistrationDict = {"reg_id": self._reg_id}
-        set_state(self._state_yaml, "registration", reg_dict)
         (self.ws_url, self.ws_token) = await self.post_devicehub_negociate()
         await self.get_websocket_params()
-        await self.put_registration(self._reg_id, android_state.get("token", ""))
-
-    async def delete_registration(self, reg_id: str) -> None:
-        LOG.debug(f"Deleting registration {reg_id}")
-        url = f"{API_REGISTRATION_ENDPOINT}/{reg_id}"
-        await self.async_request("delete", url)
-
-    async def post_registration(self) -> str:
-        LOG.debug("Requesting new registration")
-        url = f"{API_REGISTRATION_ENDPOINT}"
-        resp: dict[str, Any] = await self.async_request(
-            "post",
-            url,
-            headers={
-                **self.headers,
-                **{
-                    "Content-Type": "text/plain",
-                    "Content-Length": "0",
-                    "Accept": "text/plain",
-                },
-            },
-        )
-        return resp.get("message", "")
-
-    async def put_registration(self, reg_id: str, handler: str) -> str:
-        LOG.debug("Submitting handler for registration")
-        url = f"{API_REGISTRATION_ENDPOINT}/{reg_id}"
-        resp: dict[str, Any] = await self.async_request(
-            "put", url, json={"platform": "fcm", "handle": handler}
-        )
-        return resp.get("message", "")
 
     async def post_devicehub_negociate(self) -> tuple[str, str]:
         LOG.debug("Getting websocket url")
